@@ -6,13 +6,20 @@ taskmaster.cli.slave
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
-from taskmaster.constants import DEFAULT_LOG_LEVEL, DEFAULT_ADDRESS
+from taskmaster.constants import (
+    DEFAULT_ADDRESS,
+    DEFAULT_LOG_LEVEL,
+    DEFAULT_RETRIES,
+    DEFAULT_TIMEOUT,
+)
 
 
-def run(target, address=DEFAULT_ADDRESS, progressbar=True, log_level=DEFAULT_LOG_LEVEL):
+def run(target, address=DEFAULT_ADDRESS, progressbar=True,
+        log_level=DEFAULT_LOG_LEVEL, retries=DEFAULT_RETRIES, timeout=DEFAULT_TIMEOUT):
     from taskmaster.client import Consumer, Client
 
-    client = Client(address, log_level=log_level)
+    client = Client(address, log_level=log_level, retries=retries,
+            timeout=timeout)
 
     consumer = Consumer(client, target, progressbar=progressbar, log_level=log_level)
     consumer.start()
@@ -25,6 +32,8 @@ def main():
     parser.add_option("--address", dest="address", default=DEFAULT_ADDRESS)
     parser.add_option("--no-progress", dest="progressbar", action="store_false", default=True)
     parser.add_option("--log-level", dest="log_level", default=DEFAULT_LOG_LEVEL)
+    parser.add_option("--retries", dest="retries", default=DEFAULT_RETRIES, type=int)
+    parser.add_option("--timeout", dest="timeout", default=DEFAULT_TIMEOUT, type=int)
     (options, args) = parser.parse_args()
     if len(args) != 1:
         print 'Usage: tm-slave <callback>'
