@@ -11,3 +11,5 @@ DEFAULT_LOG_LEVEL = 'ERROR'
 DEFAULT_ITERATOR_TARGET = 'get_jobs'
 DEFAULT_CALLBACK_TARGET = 'handle_job'
 DEFAULT_BUFFER_SIZE = 10000
+DEFAULT_TIMEOUT = 2500
+DEFAULT_RETRIES = 3
